| SPEA2minstoptimeRichmond | R Documentation |
Results of SPEA2 when minimising electrical cost and maximising the minimum idle time of pumps on Richmond water network.
SPEA2minstoptimeRichmond
A data frame as produced by read_datasets(). The second
column measures time in seconds and corresponds to a maximisation problem.
LopezIbanezPhDmoocore
data(SPEA2minstoptimeRichmond)
str(SPEA2minstoptimeRichmond)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.