| CPFs | R Documentation |
The data has the only goal of providing an example of use of vorob_t() and
vorob_dev(). It has been obtained by fitting two Gaussian processes on 20
observations of a bi-objective problem, before generating conditional
simulation of both GPs at different locations and extracting non-dominated
values of coupled simulations.
CPFs
A data frame with 2967 observations on the following 3 variables.
f1first objective values.
f2second objective values.
setindices of corresponding conditional Pareto fronts.
BinGinRou2015gauparmoocore
data(CPFs)
vorob_t(CPFs, reference = c(2, 200))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.