| hv_contributions | R Documentation |
Computes the hypervolume contribution of each point of a set of points with
respect to a given reference point. Duplicated and dominated points have
zero contribution. By default, dominated points are ignored, that is, they
do not affect the contribution of other points. See the Notes below for
more details. For details about the hypervolume, see hypervolume().
hv_contributions(x, reference, maximise = FALSE, ignore_dominated = TRUE)
x |
|
reference |
|
maximise |
|
ignore_dominated |
|
The hypervolume contribution of point \vec{p} \in X is defined as
\text{hvc}(\vec{p}) = \text{hyp}(X) - \text{hyp}(X \setminus
\{\vec{p}\}). This definition implies that duplicated points have zero
contribution even if not dominated, because removing one of the duplicates
does not change the hypervolume of the remaining set. Moreover, dominated
points also have zero contribution. However, a point that is dominated by a
single (dominating) nondominated point reduces the contribution of the
latter, because removing the dominating point makes the dominated one become
nondominated.
Handling this special case is non-trivial and makes the computation more
expensive, thus the default (ignore_dominated=TRUE) ignores all dominated
points in the input, that is, their contribution is set to zero and their
presence does not affect the contribution of any other point. Setting
ignore_dominated=FALSE will consider dominated points according to the
mathematical definition given above, but the computation will be slower.
When the input only consists of mutually nondominated points, the value of
ignore_dominated does not change the result, but the default value is
significantly faster.
The current implementation uses a O(n\log n) dimension-sweep
algorithm for 2D. With ignore_dominated=TRUE, the 3D case uses the HVC3D
algorithm \citepGueFon2017hv4d, which has O(n\log n) complexity.
Otherwise, the implementation uses the naive algorithm that requires
calculating the hypervolume |X|+1 times.
numeric()
A numerical vector
Manuel López-Ibáñez
hypervolume()
x <- matrix(c(5,1, 1,5, 4,2, 4,4, 5,1), ncol=2, byrow=TRUE)
hv_contributions(x, reference=c(6,6))
# hvc[(5,1)] = 0 = duplicated
# hvc[(1,5)] = 3 = (4 - 1) * (6 - 5)
# hvc[(4,2)] = 3 = (5 - 4) * (5 - 2)
# hvc[(4,4)] = 0 = dominated
# hvc[(5,1)] = 0 = duplicated
hv_contributions(x, reference=c(6,6), ignore_dominated = FALSE)
# hvc[(5,1)] = 0 = duplicated
# hvc[(1,5)] = 3 = (4 - 1) * (6 - 5)
# hvc[(4,2)] = 2 = (5 - 4) * (4 - 2)
# hvc[(4,4)] = 0 = dominated
# hvc[(5,1)] = 0 = duplicated
data(SPEA2minstoptimeRichmond)
# The second objective must be maximized
# We calculate the hypervolume contribution of each point of the union of all sets.
hv_contributions(SPEA2minstoptimeRichmond[, 1:2], reference = c(250, 0),
maximise = c(FALSE, TRUE))
# Duplicated points show zero contribution above, even if not
# dominated. However, filter_dominated removes all duplicates except
# one. Hence, there are more points below with nonzero contribution.
hv_contributions(filter_dominated(SPEA2minstoptimeRichmond[, 1:2], maximise = c(FALSE, TRUE)),
reference = c(250, 0), maximise = c(FALSE, TRUE))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.